@@ -3,9 +3,9 @@ from time import sleep
 from random import randint
 from os import system
 
-import f61d.LOGO
+import f61d.LOGO as LOGO
 
-print(LOGO)
+print(LOGO.randlogo())
 print("Welcome to F61D")
 
 help_cont = {}
